.. _updates:

Community Updates
=================

GitHub
------

The best way to track the development of time2relax is through `the GitHub
repo`_.

.. _the GitHub repo: https://github.com/rwanyoike/time2relax

.. include:: ../HISTORY.rst
